@@ -21,7 +21,7 @@
 #include "calendarview_debug.h"
 
 #include <Akonadi/CalendarUtils>
-#include <Akonadi/ETMCalendar>
+#include <Akonadi/EntityTreeModel>
 #include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/KCalPrefs>
@@ -207,6 +207,7 @@ public:
     using DecorationList = QList<EventViews::CalendarDecoration::Decoration *>;
 
 public:
+    void setCalendarName(const QString &calendarName);
     void setAgenda(Agenda *agenda);
     bool createDayLabels(const KCalendarCore::DateList &dates, bool withDayLabel, const QStringList &decos, const QStringList &enabledDecos);
     void setWeekWidth(int width);
@@ -228,6 +229,7 @@ private:
     const bool mIsSideBySide;
 
     Agenda *mAgenda = nullptr;
+    KSqueezedTextLabel *mCalendarNameLabel = nullptr;
     QWidget *mDayLabels = nullptr;
     AgendaHeaderLayout *mDayLabelsLayout = nullptr;
     QWidget *mWeekLabelBox = nullptr;
@@ -239,23 +241,35 @@ AgendaHeader::AgendaHeader(bool isSideBySide, QWidget *parent)
     : QWidget(parent)
     , mIsSideBySide(isSideBySide)
 {
-    auto layout = new QHBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(SPACING);
+
+    if (mIsSideBySide) {
+        mCalendarNameLabel = new KSqueezedTextLabel(this);
+        mCalendarNameLabel->setAlignment(Qt::AlignCenter);
+        layout->addWidget(mCalendarNameLabel);
+    }
+
+    auto *daysWidget = new QWidget(this);
+    layout->addWidget(daysWidget);
+
+    auto daysLayout = new QHBoxLayout(daysWidget);
+    daysLayout->setContentsMargins(0, 0, 0, 0);
+    daysLayout->setSpacing(SPACING);
 
     if (!mIsSideBySide) {
-        mWeekLabelBox = new QWidget(this);
+        mWeekLabelBox = new QWidget(daysWidget);
         auto weekLabelBoxLayout = new QVBoxLayout(mWeekLabelBox);
         weekLabelBoxLayout->setContentsMargins(0, 0, 0, 0);
         weekLabelBoxLayout->setSpacing(0);
-        layout->addWidget(mWeekLabelBox);
+        daysLayout->addWidget(mWeekLabelBox);
     }
 
-    mDayLabels = new QWidget(this);
+    mDayLabels = new QWidget(daysWidget);
     mDayLabelsLayout = new AgendaHeaderLayout(mDayLabels);
     mDayLabelsLayout->setContentsMargins(0, 0, 0, 0);
-    layout->addWidget(mDayLabels);
-    layout->setStretchFactor(mDayLabels, 1);
+    daysLayout->addWidget(mDayLabels);
+    daysLayout->setStretchFactor(mDayLabels, 1);
 }
 
 void AgendaHeader::setAgenda(Agenda *agenda)
@@ -263,6 +277,13 @@ void AgendaHeader::setAgenda(Agenda *agenda)
     mAgenda = agenda;
 }
 
+void AgendaHeader::setCalendarName(const QString &calendarName)
+{
+    if (mCalendarNameLabel) {
+        mCalendarNameLabel->setText(calendarName);
+    }
+}
+
 void AgendaHeader::updateMargins()
 {
     const int frameWidth = mAgenda ? mAgenda->scrollArea()->frameWidth() : 0;
@@ -422,8 +443,7 @@ void AgendaHeader::loadDecorations(const QStringList &decorations, const QString
 
 CalendarDecoration::Decoration *AgendaHeader::loadCalendarDecoration(const QString &name)
 {
-    auto result = KPluginFactory::instantiatePlugin<CalendarDecoration::Decoration>(
-        KPluginMetaData(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/korganizer/") + name));
+    auto result = KPluginFactory::instantiatePlugin<CalendarDecoration::Decoration>(KPluginMetaData(QStringLiteral("pim6/korganizer/") + name));
 
     if (result) {
         return result.plugin;
@@ -472,7 +492,7 @@ public:
     int mColumns = 1;
     const EventIndicator::Location mLocation;
     QPixmap mPixmap;
-    QVector<bool> mEnabled;
+    QList<bool> mEnabled;
 
 private:
     EventIndicator *const q;
@@ -531,7 +551,7 @@ void EventIndicator::enableColumn(int column, bool enable)
 ////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////
 
-class EventViews::AgendaViewPrivate : public Akonadi::ETMCalendar::CalendarObserver
+class EventViews::AgendaViewPrivate : public KCalendarCore::Calendar::CalendarObserver
 {
     AgendaView *const q;
 
@@ -544,7 +564,6 @@ public:
         , mViewCalendar(MultiViewCalendar::Ptr(new MultiViewCalendar()))
     {
         mViewCalendar->mAgendaView = q;
-        mViewCalendar->setETMCalendar(q->calendar());
     }
 
 public:
@@ -569,10 +588,10 @@ public:
     EventIndicator *mEventIndicatorTop = nullptr;
     EventIndicator *mEventIndicatorBottom = nullptr;
 
-    QVector<int> mMinY;
-    QVector<int> mMaxY;
+    QList<int> mMinY;
+    QList<int> mMaxY;
 
-    QVector<bool> mHolidayMask;
+    QList<bool> mHolidayMask;
 
     QDateTime mTimeSpanBegin;
     QDateTime mTimeSpanEnd;
@@ -791,7 +810,8 @@ void AgendaViewPrivate::calendarIncidenceChanged(const KCalendarCore::Incidence:
 
     AgendaItem::List agendaItems = this->agendaItems(incidence->uid());
     if (agendaItems.isEmpty()) {
-        qCWarning(CALENDARVIEW_LOG) << "AgendaView::calendarIncidenceChanged() Invalid agendaItem for incidence " << incidence->uid();
+        // Don't warn - it's possible the incidence has been changed in another calendar that we do not display.
+        // qCWarning(CALENDARVIEW_LOG) << "AgendaView::calendarIncidenceChanged() Invalid agendaItem for incidence " << incidence->uid();
         return;
     }
 
@@ -1139,6 +1159,9 @@ void AgendaView::init(QDate start, QDate end)
     auto scrollArea = new AgendaScrollArea(false, this, d->mIsInteractive, agendaFrame);
     d->mAgenda = scrollArea->agenda();
     d->mAgenda->verticalScrollBar()->installEventFilter(this);
+    d->mAgenda->setCalendar(d->mViewCalendar);
+
+    d->mAllDayAgenda->setCalendar(d->mViewCalendar);
 
     // Create event indicator bars
     d->mEventIndicatorTop = new EventIndicator(EventIndicator::Top, scrollArea->viewport());
@@ -1211,6 +1234,39 @@ AgendaView::~AgendaView()
     }
 }
 
+void AgendaView::addCalendar(const Akonadi::CollectionCalendar::Ptr &calendar)
+{
+    EventView::addCalendar(calendar);
+
+    if (!d->mViewCalendar->calendarForCollection(calendar->collection()).isNull()) {
+        return;
+    }
+
+    auto view = AkonadiViewCalendar::Ptr::create();
+    view->mCalendar = calendar;
+    view->mAgendaView = this;
+    addCalendar(view);
+}
+
+void AgendaView::removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar)
+{
+    EventView::removeCalendar(calendar);
+
+    auto cal = std::find_if(d->mViewCalendar->mSubCalendars.cbegin(), d->mViewCalendar->mSubCalendars.cend(), [calendar](const auto &subcal) {
+        if (auto akonadiCal = qSharedPointerDynamicCast<AkonadiViewCalendar>(subcal); akonadiCal) {
+            // TODO: FIXME: the pointer-based comparision MUST succeed here, not collection-based comparison!!!
+            return akonadiCal->mCalendar->collection() == calendar->collection();
+        }
+        return false;
+    });
+
+    if (cal != d->mViewCalendar->mSubCalendars.end()) {
+        calendar->unregisterObserver(d.get());
+        d->mViewCalendar->removeCalendar(*cal);
+        setChanges(EventViews::EventView::ResourcesChanged);
+        updateView();
+    }
+}
 void AgendaView::showEvent(QShowEvent *showEvent)
 {
     EventView::showEvent(showEvent);
@@ -1249,23 +1305,20 @@ KCalendarCore::Calendar::Ptr AgendaView::calendar2(const QString &incidenceIdent
     return {};
 }
 
-void AgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &cal)
-{
-    if (calendar()) {
-        calendar()->unregisterObserver(d.get());
-    }
-    Q_ASSERT(cal);
-    EventView::setCalendar(cal);
-    calendar()->registerObserver(d.get());
-    d->mViewCalendar->setETMCalendar(cal);
-    d->mAgenda->setCalendar(d->mViewCalendar);
-    d->mAllDayAgenda->setCalendar(d->mViewCalendar);
-}
-
 void AgendaView::addCalendar(const ViewCalendar::Ptr &cal)
 {
+    const bool isFirstCalendar = d->mViewCalendar->calendarCount() == 0;
+
     d->mViewCalendar->addCalendar(cal);
     cal->getCalendar()->registerObserver(d.get());
+
+    EventView::Changes changes = EventView::ResourcesChanged;
+    if (isFirstCalendar) {
+        changes |= EventView::DatesChanged; // we need to initialize the columns as well
+    }
+
+    setChanges(changes);
+    updateView();
 }
 
 void AgendaView::connectAgenda(Agenda *agenda, Agenda *otherAgenda)
@@ -1318,7 +1371,8 @@ void AgendaView::slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &inc
     Akonadi::Item item = d->mViewCalendar->item(incidence);
     // qDebug() << "wanna see the popup for " << incidence->uid() << item.id();
     if (item.isValid()) {
-        Q_EMIT showIncidencePopupSignal(item, date);
+        const auto calendar = calendar3(item);
+        Q_EMIT showIncidencePopupSignal(calendar, item, date);
     }
 }
 
@@ -1803,7 +1857,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
 
     bool result;
     if (addIncidence) {
-        Akonadi::Collection collection = calendar()->collection(collectionId);
+        auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), collectionId);
         result = changer()->createIncidence(incidence, collection, this) != -1;
     } else {
         KCalendarCore::Incidence::Ptr oldIncidence(Akonadi::CalendarUtils::incidence(aitem));
@@ -1875,30 +1929,19 @@ void AgendaView::showIncidences(const Akonadi::Item::List &incidences, const QDa
 {
     Q_UNUSED(date)
 
-    if (!calendar()) {
-        qCCritical(CALENDARVIEW_LOG) << "No Calendar set";
-        return;
-    }
-
-    // we must check if they are not filtered; if they are, remove the filter
-    KCalendarCore::CalFilter *filter = calendar()->filter();
-    bool wehaveall = true;
-    if (filter) {
-        for (const Akonadi::Item &aitem : incidences) {
-            if (!(wehaveall = filter->filterIncidence(Akonadi::CalendarUtils::incidence(aitem)))) {
-                break;
-            }
-        }
-    }
-
-    if (!wehaveall) {
-        calendar()->setFilter(nullptr);
-    }
-
     QDateTime start = Akonadi::CalendarUtils::incidence(incidences.first())->dtStart().toLocalTime();
     QDateTime end = Akonadi::CalendarUtils::incidence(incidences.first())->dateTime(KCalendarCore::Incidence::RoleEnd).toLocalTime();
     Akonadi::Item first = incidences.first();
     for (const Akonadi::Item &aitem : incidences) {
+        // we must check if they are not filtered; if they are, remove the filter
+        const auto &cal = d->mViewCalendar->calendarForCollection(aitem.storageCollectionId());
+        if (cal && cal->filter()) {
+            const bool filtered = !cal->filter()->filterIncidence(Akonadi::CalendarUtils::incidence(aitem));
+            if (filtered) {
+                cal->setFilter(nullptr);
+            }
+        }
+
         if (Akonadi::CalendarUtils::incidence(aitem)->dtStart().toLocalTime() < start) {
             first = aitem;
         }
@@ -1922,8 +1965,13 @@ void AgendaView::fillAgenda()
         return;
     }
 
-    if (d->mViewCalendar->calendars() == 0) {
-        qCWarning(CALENDARVIEW_LOG) << "No calendar is set";
+    const QString selectedAgendaId = d->mAgenda->lastSelectedItemUid();
+    const QString selectedAllDayAgendaId = d->mAllDayAgenda->lastSelectedItemUid();
+
+    enableAgendaUpdate(true);
+    d->clearView();
+
+    if (d->mViewCalendar->calendarCount() == 0) {
         return;
     }
 
@@ -1934,12 +1982,6 @@ void AgendaView::fillAgenda()
 
     /* Remember the item Ids of the selected items. In case one of the
      * items was deleted and re-added, we want to reselect it. */
-    const QString selectedAgendaId = d->mAgenda->lastSelectedItemUid();
-    const QString selectedAllDayAgendaId = d->mAllDayAgenda->lastSelectedItemUid();
-
-    enableAgendaUpdate(true);
-    d->clearView();
-
     if (changes().testFlag(DatesChanged)) {
         d->mAllDayAgenda->changeColumns(d->mSelectedDates.count());
         d->mAgenda->changeColumns(d->mSelectedDates.count());
@@ -2036,7 +2078,7 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
         // the range
         const QDateTime startDateTimeWithOffset = firstVisibleDateTime.addDays(-eventDuration);
 
-        KCalendarCore::OccurrenceIterator rIt(*calendar(), incidence, startDateTimeWithOffset, lastVisibleDateTime);
+        KCalendarCore::OccurrenceIterator rIt(*calendar2(incidence), incidence, startDateTimeWithOffset, lastVisibleDateTime);
         while (rIt.hasNext()) {
             rIt.next();
             auto occurrenceDate = rIt.occurrenceStartDate().toLocalTime();
@@ -2221,8 +2263,8 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
     QDateTime newTime(day, time, Qt::LocalTime);
 
     for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
-        const Akonadi::Item existingItem = calendar()->item(incidence);
-        const bool existsInSameCollection = existingItem.isValid() && (existingItem.storageCollectionId() == collectionId() || collectionId() == -1);
+        const Akonadi::Item existingItem = d->mViewCalendar->item(incidence);
+        const bool existsInSameCollection = existingItem.isValid();
 
         if (existingItem.isValid() && existsInSameCollection) {
             auto newIncidence = existingItem.payload<KCalendarCore::Incidence::Ptr>();
@@ -2240,8 +2282,8 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
             // The drop came from another application.  Create a new incidence.
             setDateTime(incidence, newTime, allDay);
             incidence->setUid(KCalendarCore::CalFormat::createUniqueId());
-            Akonadi::Collection collection(collectionId());
-            const bool added = -1 != changer()->createIncidence(incidence, collection, this);
+            // Drop into the default collection
+            const bool added = -1 != changer()->createIncidence(incidence, Akonadi::Collection(), this);
 
             if (added) {
                 // TODO: make async
@@ -2255,11 +2297,6 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
 
 void AgendaView::startDrag(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    if (!calendar()) {
-        qCCritical(CALENDARVIEW_LOG) << "No Calendar set";
-        return;
-    }
-
     const Akonadi::Item item = d->mViewCalendar->item(incidence);
     if (item.isValid()) {
         startDrag(item);
@@ -2268,10 +2305,6 @@ void AgendaView::startDrag(const KCalendarCore::Incidence::Ptr &incidence)
 
 void AgendaView::startDrag(const Akonadi::Item &incidence)
 {
-    if (!calendar()) {
-        qCCritical(CALENDARVIEW_LOG) << "No Calendar set";
-        return;
-    }
     if (QDrag *drag = CalendarSupport::createDrag(incidence, this)) {
         drag->exec();
     }
@@ -2285,7 +2318,7 @@ void AgendaView::readSettings()
 
 void AgendaView::readSettings(const KConfig *config)
 {
-    const KConfigGroup group = config->group("Views");
+    const KConfigGroup group = config->group(QStringLiteral("Views"));
 
     const QList<int> sizes = group.readEntry("Separator AgendaView", QList<int>());
 
@@ -2299,19 +2332,19 @@ void AgendaView::readSettings(const KConfig *config)
 
 void AgendaView::writeSettings(KConfig *config)
 {
-    KConfigGroup group = config->group("Views");
+    KConfigGroup group = config->group(QStringLiteral("Views"));
 
     QList<int> list = d->mSplitterAgenda->sizes();
     group.writeEntry("Separator AgendaView", list);
 }
 
-QVector<bool> AgendaView::busyDayMask() const
+QList<bool> AgendaView::busyDayMask() const
 {
     if (d->mSelectedDates.isEmpty() || !d->mSelectedDates[0].isValid()) {
         return {};
     }
 
-    QVector<bool> busyDayMask;
+    QList<bool> busyDayMask;
     busyDayMask.resize(d->mSelectedDates.count());
 
     for (int i = 0; i < d->mSelectedDates.count(); ++i) {
@@ -2461,6 +2494,8 @@ QSplitter *AgendaView::splitter() const
 
 bool AgendaView::filterByCollectionSelection(const KCalendarCore::Incidence::Ptr &incidence)
 {
+    return true;
+    /*
     const Akonadi::Item item = d->mViewCalendar->item(incidence);
 
     if (!item.isValid()) {
@@ -2471,11 +2506,8 @@ bool AgendaView::filterByCollectionSelection(const KCalendarCore::Incidence::Ptr
         return customCollectionSelection()->contains(item.parentCollection().id());
     }
 
-    if (collectionId() < 0) {
-        return true;
-    } else {
-        return collectionId() == item.storageCollectionId();
-    }
+    return true;
+    */
 }
 
 void AgendaView::alignAgendas()
@@ -2494,6 +2526,11 @@ void AgendaView::setChanges(EventView::Changes changes)
     d->setChanges(changes);
 }
 
+void AgendaView::setTitle(const QString &title)
+{
+    d->mTopDayLabelsFrame->setCalendarName(title);
+}
+
 void AgendaView::scheduleUpdateEventIndicators()
 {
     if (!d->mUpdateEventIndicatorsScheduled) {
@@ -2503,3 +2540,5 @@ void AgendaView::scheduleUpdateEventIndicators()
 }
 
 #include "agendaview.moc"
+
+#include "moc_agendaview.cpp"
