@@ -77,35 +77,37 @@ public:
         MAX_DAY_COUNT = 42 // (6 * 7)
     };
 
+    void addCalendar(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+
     /** Returns number of currently shown dates. */
-    Q_REQUIRED_RESULT int currentDateCount() const override;
+    [[nodiscard]] int currentDateCount() const override;
 
     /** returns the currently selected events */
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override;
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() const override;
 
     /** returns the currently selected incidence's dates */
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() const override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() const override;
 
     /** return the default start/end date/time for new events   */
     bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const override;
 
     /** start-datetime of selection */
-    Q_REQUIRED_RESULT QDateTime selectionStart() const override;
+    [[nodiscard]] QDateTime selectionStart() const override;
 
     /** end-datetime of selection */
-    Q_REQUIRED_RESULT QDateTime selectionEnd() const override;
+    [[nodiscard]] QDateTime selectionEnd() const override;
 
     /** returns true if selection is for whole day */
-    Q_REQUIRED_RESULT bool selectedIsAllDay() const;
+    [[nodiscard]] bool selectedIsAllDay() const;
 
     /** make selected start/end invalid */
     void deleteSelectedDateTime();
 
     /** returns if only a single cell is selected, or a range of cells */
-    Q_REQUIRED_RESULT bool selectedIsSingleCell() const;
+    [[nodiscard]] bool selectedIsSingleCell() const;
 
     /* reimp from EventView */
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) override;
     virtual void addCalendar(const ViewCalendar::Ptr &cal);
 
     QSplitter *splitter() const;
@@ -113,16 +115,16 @@ public:
     // FIXME: we already have startDateTime() and endDateTime() in the base class
 
     /** First shown day */
-    Q_REQUIRED_RESULT QDate startDate() const;
+    [[nodiscard]] QDate startDate() const;
     /** Last shown day */
-    Q_REQUIRED_RESULT QDate endDate() const;
+    [[nodiscard]] QDate endDate() const;
 
     /** Update event belonging to agenda item
         If the incidence is multi-day, item is the first one
     */
     void updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::Collection::Id collectionId);
 
-    Q_REQUIRED_RESULT QVector<bool> busyDayMask() const;
+    [[nodiscard]] QList<bool> busyDayMask() const;
 
     /**
      * Return calendar object for a concrete incidence.
@@ -166,9 +168,11 @@ public:
 
     void setChanges(EventView::Changes) override;
 
+    void setTitle(const QString &title);
+
 Q_SIGNALS:
     void showNewEventPopupSignal();
-    void showIncidencePopupSignal(const Akonadi::Item &, const QDate &);
+    void showIncidencePopupSignal(const Akonadi::CollectionCalendar::Ptr &, const Akonadi::Item &, const QDate &);
     void zoomViewHorizontally(const QDate &, int count);
 
     void timeSpanSelectionChanged();
@@ -214,6 +218,7 @@ protected Q_SLOTS:
 
 protected:
     void showEvent(QShowEvent *showEvent) override;
+    bool eventFilter(QObject *object, QEvent *event) override;
 
 private Q_SLOTS:
     void slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &incidence, QDate date);
@@ -239,4 +244,3 @@ private:
     std::unique_ptr<AgendaViewPrivate> const d;
 };
 }
-
