@@ -11,10 +11,10 @@
 #pragma once
 
 #include "eventview.h"
-#include <Akonadi/ETMCalendar>
 #include <Akonadi/IncidenceChanger>
 
 #include <QPointer>
+#include <akonadi/collectioncalendar.h>
 
 class KJob;
 class TodoCategoriesDelegate;
@@ -23,11 +23,6 @@ class TodoViewQuickSearch;
 class TodoViewSortFilterProxyModel;
 class TodoViewView;
 
-namespace CalendarSupport
-{
-class KDatePickerPopup;
-}
-
 namespace Akonadi
 {
 class ETMViewStateSaver;
@@ -39,8 +34,12 @@ class QModelIndex;
 class QToolButton;
 class QTimer;
 class KConfig;
+class KDatePickerPopup;
 namespace EventViews
 {
+
+class CalendarFilterModel;
+
 /**
  * This class provides a view for Todo items.
 
@@ -57,11 +56,13 @@ public:
     TodoView(const EventViews::PrefsPtr &preferences, bool sidebarView, QWidget *parent);
     ~TodoView() override;
 
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &) override;
+    void setModel(QAbstractItemModel *model) override;
+    void addCalendar(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar) override;
 
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override;
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() const override;
-    Q_REQUIRED_RESULT int currentDateCount() const override
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() const override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() const override;
+    [[nodiscard]] int currentDateCount() const override
     {
         return 0;
     }
@@ -77,9 +78,9 @@ public:
     /** documentation in baseview.h */
     void getHighlightMode(bool &highlightEvents, bool &highlightTodos, bool &highlightJournals);
 
-    Q_REQUIRED_RESULT bool usesFullWindow();
+    [[nodiscard]] bool usesFullWindow();
 
-    Q_REQUIRED_RESULT bool supportsDateRangeSelection() const
+    [[nodiscard]] bool supportsDateRangeSelection() const
     {
         return false;
     }
@@ -116,20 +117,20 @@ protected Q_SLOTS:
     void copyTodoToDate(QDate date);
 
 private Q_SLOTS:
-    void scheduleResizeColumns();
-    void resizeColumns();
-    void itemDoubleClicked(const QModelIndex &index);
-    void setNewDate(QDate date);
-    void setStartDate(QDate date);
-    void setNewPercentage(QAction *action);
-    void setNewPriority(QAction *action);
-    void changedCategories(QAction *action);
-    void setFullView(bool fullView);
+    EVENTVIEWS_NO_EXPORT void scheduleResizeColumns();
+    EVENTVIEWS_NO_EXPORT void resizeColumns();
+    EVENTVIEWS_NO_EXPORT void itemDoubleClicked(const QModelIndex &index);
+    EVENTVIEWS_NO_EXPORT void setNewDate(QDate date);
+    EVENTVIEWS_NO_EXPORT void setStartDate(QDate date);
+    EVENTVIEWS_NO_EXPORT void setNewPercentage(QAction *action);
+    EVENTVIEWS_NO_EXPORT void setNewPriority(QAction *action);
+    EVENTVIEWS_NO_EXPORT void changedCategories(QAction *action);
+    EVENTVIEWS_NO_EXPORT void setFullView(bool fullView);
 
-    void setFlatView(bool flatView, bool notifyOtherViews = true);
+    EVENTVIEWS_NO_EXPORT void setFlatView(bool flatView, bool notifyOtherViews = true);
 
-    void onRowsInserted(const QModelIndex &parent, int start, int end);
-    void onTagsFetched(KJob *);
+    EVENTVIEWS_NO_EXPORT void onRowsInserted(const QModelIndex &parent, int start, int end);
+    EVENTVIEWS_NO_EXPORT void onTagsFetched(KJob *);
 
 Q_SIGNALS:
     void purgeCompletedSignal();
@@ -144,8 +145,8 @@ Q_SIGNALS:
     void createEvent(const Akonadi::Item &item);
 
 private:
-    QMenu *createCategoryPopupMenu();
-    QString stateSaverGroup() const;
+    EVENTVIEWS_NO_EXPORT QMenu *createCategoryPopupMenu();
+    EVENTVIEWS_NO_EXPORT QString stateSaverGroup() const;
 
     /** Creates a new todo with the given text as summary under the given parent */
     void addTodo(const QString &summary, const Akonadi::Item &parentItem, const QStringList &categories = QStringList());
@@ -153,6 +154,7 @@ private:
     TodoViewView *mView = nullptr;
     TodoViewSortFilterProxyModel *mProxyModel = nullptr;
     TodoCategoriesDelegate *mCategoriesDelegate = nullptr;
+    std::unique_ptr<CalendarFilterModel> mCalendarFilterModel;
 
     TodoViewQuickSearch *mQuickSearch = nullptr;
     TodoViewQuickAddLine *mQuickAdd = nullptr;
@@ -160,8 +162,8 @@ private:
     QToolButton *mFlatViewButton = nullptr;
 
     QMenu *mItemPopupMenu = nullptr;
-    CalendarSupport::KDatePickerPopup *mCopyPopupMenu = nullptr;
-    CalendarSupport::KDatePickerPopup *mMovePopupMenu = nullptr;
+    KDatePickerPopup *mCopyPopupMenu = nullptr;
+    KDatePickerPopup *mMovePopupMenu = nullptr;
     QMenu *mPriorityPopupMenu = nullptr;
     QMenu *mPercentageCompletedPopupMenu = nullptr;
     QList<QAction *> mItemPopupMenuItemOnlyEntries;
@@ -179,4 +181,3 @@ private:
     QTimer *mResizeColumnsTimer = nullptr;
 };
 }
-
